@@ -2,30 +2,31 @@
 #' 
 #' predicates are JSON scripts for passing to GBIF offline downloads API.
 #' https://www.gbif.org/developer/occurrence
-#' @noRd
-#' @keywords Internal
 #' @importFrom potions pour
 #' @importFrom jsonlite toJSON 
 #' @importFrom jsonlite unbox
+#' @noRd
+#' @keywords Internal
 build_predicates <- function(
   df, # where df is returned by galah_filter()
+  location,
   format = "SIMPLE_CSV"
 ){ 
-
   if(nrow(df) < 1){
     return(NULL)
   }
 
-  predicates_list <- parse_predicates(df)
-  if(nrow(df) > 1){
+  predicates_list <- c(
+    parse_predicates(df),
+    parse_predicates_spatial(location))
+  
+  if(length(predicates_list) > 1){
      predicates_list <- list(
       type = unbox("and"),
-      predicates = parse_predicates(df)
+      predicates = predicates_list
     )
-  }else{
-     predicates_list <- parse_predicates(df)[[1]]
   }
-
+  
   data_list <- list(
     creator = unbox(pour("user", "username", .pkg = "galah")),
     notificationAddresses = pour("user", "email", .pkg = "galah"),
@@ -37,7 +38,38 @@ build_predicates <- function(
   toJSON(data_list)
 }
 
-# parse galah_filter result into predicate format
+#' most code borrowed from `build_query_gbif()`
+#' @noRd
+#' @keywords Internal
+parse_predicates_spatial <- function(location){
+  if(!is.null(location)) {
+    # if location is for a point radius vs polygon/bbox
+    if(!is.null(names(location))){
+      if(all(!is.null(location$radius))) { # `galah_radius()` will always pass radius argument
+        list(type = unbox("geoDistance"),
+             latitude = unbox(location$lat),
+             longitude = unbox(location$lon),
+             distance = unbox(paste0(location$radius, "km"))) |>
+          list()
+      }else{
+        list(type = unbox("within"), 
+             geometry = unbox(location)) |>
+          list()
+      }
+    }else{
+      list(type = unbox("within"), 
+           geometry = unbox(location)) |>
+        list()
+    }
+  }else{
+    NULL
+  }
+}
+
+#' parse galah_filter result into predicate format
+#' @importFrom jsonlite unbox
+#' @noRd
+#' @keywords Internal
 parse_predicates <- function(df){
   json_text <- lapply(
     split(df, seq_len(nrow(df))),
@@ -58,8 +90,7 @@ parse_predicates <- function(df){
     names(json_text) <- NULL
     return(json_text)
 }
-# NOTE: currently missing: `within` (geolocate), `or`, `in`, `isNull`, `isNotNull`
-# Q: how to add taxonomic names to gbif schema?
+# NOTE: currently missing: `or`, `in`, `isNull`, `isNotNull`
 
 # test object:
 # df <- galah_filter(year == 1850)
