@@ -1,24 +1,46 @@
 test_that("galah_apply_profile filters counts", {
   skip_if_offline()
   without_profile <- galah_call() |>
-    atlas_counts()
+    count() |>
+    collect()
   with_profile <- galah_call() |>
-    galah_apply_profile(ALA) |>
-    atlas_counts()
-  expect_gt(with_profile[[1]], 0)
-  expect_equal(class(without_profile), class(with_profile))
-  expect_lt(with_profile[[1]], without_profile[[1]])
-  # add dplyr syntax
-  with_profile_2 <- request_data() |>
     apply_profile(ALA) |>
     count() |>
     collect()
+  expect_gt(with_profile$count, 0)
+  expect_equal(class(without_profile), class(with_profile))
+  expect_lt(with_profile$count, without_profile$count)
+  # add dplyr syntax
+  with_profile_2 <- request_data() |>
+    galah_apply_profile(ALA) |>
+    atlas_counts()
   expect_equal(with_profile, with_profile_2)
 })
 
+test_that("galah_apply_profile filters species", {
+  skip_if_offline()
+  galah_config(email = "ala4r@ala.org.au", 
+               atlas = "Australia", 
+               run_checks = FALSE)
+  without_profile <- galah_call(type = "species") |>
+    identify("Crinia") |>
+    select(counts, group = "taxonomy") |>
+    collect()
+  with_profile <- galah_call(type = "species") |>
+    identify("Crinia") |>
+    select(counts, group = "taxonomy") |>
+    apply_profile(ALA) |>
+    collect()
+  expect_equal(ncol(with_profile), ncol(without_profile))
+  expect_lte(nrow(with_profile), nrow(without_profile))
+  expect_true(all(with_profile$count <= without_profile$count))
+})
+
 test_that("galah_apply_profile filters occurrences", {
   skip_if_offline()
-  galah_config(email = "ala4r@ala.org.au", atlas = "Australia", run_checks = FALSE)
+  galah_config(email = "ala4r@ala.org.au", 
+               atlas = "Australia", 
+               run_checks = FALSE)
   without_profile <- galah_call() |>
     galah_identify("Acanthorhynchus tenuirostris") |>
     galah_filter(year == 2012) |>
